@@ -36,13 +36,13 @@
 #'   of \eqn{ {\boldsymbol {\eta}}_t = {\bf y}_t - \widetilde{\bf D}{\bf z}_t}
 #'   at lag \eqn{k}.
 #' @param twostep Logical. If \code{FALSE} (the default), then standard
-#'   procedures (see \code{\link{factors}}) will be implemented to estimate
+#'   procedures (see \code{\link{Factors}}) will be implemented to estimate
 #'   \eqn{r} and \eqn{{\bf A}}. If \code{TRUE}, then a two step estimation
-#'   procedure (see \code{\link{factors}}) will be implemented to estimate
+#'   procedure (see \code{\link{Factors}}) will be implemented to estimate
 #'   \eqn{r} and \eqn{{\bf A}}.
 
-#' @seealso \code{\link{factors}}.
-#' @return An object of class "HDSReg" is a list containing the following
+#' @seealso \code{\link{Factors}}.
+#' @return An object of class "factors" is a list containing the following
 #'   components:
 #'
 #'   \item{factor_num}{The estimated number of factors \eqn{\hat{r}}.}
@@ -50,6 +50,8 @@
 #'   matrix \eqn{\widetilde{\bf D}} if \code{D} is not given.}
 #'   \item{loading.mat}{The estimated \eqn{p \times m} factor loading matrix
 #'   \eqn{{\bf \widehat{A}}}.}
+#'   \item{lag.k}{the time lag used in function.}
+#'   \item{method}{a character string indicating what method was performed.}
 #' @references Chang, J., Guo, B. & Yao, Q. (2015).  \emph{High dimensional
 #'   stochastic regression with latent factors, endogeneity and nonlinearity},
 #'   Journal of Econometrics, Vol. 189, pp. 297–312.
@@ -106,10 +108,14 @@ HDSReg <- function (Y,Z,D=NULL,lag.k=1,twostep=FALSE) {
   
   eta <- t(Y)-MatMult(D, t(Z))
   eta <- t(eta)
-  factor_list <- factors(eta, lag.k, twostep)
+  factor_list <- Factors(eta, lag.k, twostep)
   r <- factor_list$factor_num
   loading.mat <- factor_list$loading.mat
-  outlist <- list(reg.coff.mat=D, factor_num=r, loading.mat=loading.mat)
-  class(outlist) <- c("HDSReg")
-  return(outlist)
+  METHOD <- "High dimensional stochastic regression with latent factors"
+  #outlist <- list(reg.coff.mat=D, factor_num=r, loading.mat=loading.mat)
+  #class(outlist) <- c("HDSReg")
+  structure(list(factor_num = r, reg.coff.mat = D, loading.mat = loading.mat, 
+                 lag.k=factor_list$lag.k, method = METHOD),
+            class = "factors")
+  #return(outlist)
 }
